/*\
|*|
|*|  :: cookies.js ::
|*|
|*|  A complete cookies reader/writer framework with full unicode support.
|*|
|*|  https://developer.mozilla.org/en-US/docs/DOM/document.cookie
|*|
|*|  This framework is released under the GNU Public License, version 3 or later.
|*|  http://www.gnu.org/licenses/gpl-3.0-standalone.html
|*|
|*|  Syntaxes:
|*|
|*|  * docCookies.setItem(name, value[, end[, path[, domain[, secure]]]])
|*|  * docCookies.getItem(name)
|*|  * docCookies.removeItem(name[, path], domain)
|*|  * docCookies.hasItem(name)
|*|  * docCookies.keys()
|*|
\*/

var docCookies = {
  getItem: function (sKey) {
    return decodeURIComponent(document.cookie.replace(new RegExp("(?:(?:^|.*;)\\s*" + encodeURIComponent(sKey).replace(/[\-\.\+\*]/g, "\\$&") + "\\s*\\=\\s*([^;]*).*$)|^.*$"), "$1")) || null;
  },
  setItem: function (sKey, sValue, vEnd, sPath, sDomain, bSecure) {
    if (!sKey || /^(?:expires|max\-age|path|domain|secure)$/i.test(sKey)) { return false; }
    var sExpires = "";
    if (vEnd) {
      switch (vEnd.constructor) {
        case Number:
          sExpires = vEnd === Infinity ? "; expires=Fri, 31 Dec 9999 23:59:59 GMT" : "; max-age=" + vEnd;
          break;
        case String:
          sExpires = "; expires=" + vEnd;
          break;
        case Date:
          sExpires = "; expires=" + vEnd.toUTCString();
          break;
      }
    }
    document.cookie = encodeURIComponent(sKey) + "=" + encodeURIComponent(sValue) + sExpires + (sDomain ? "; domain=" + sDomain : "") + (sPath ? "; path=" + sPath : "") + (bSecure ? "; secure" : "");
    return true;
  },
  removeItem: function (sKey, sPath, sDomain) {
    if (!sKey || !this.hasItem(sKey)) { return false; }
    document.cookie = encodeURIComponent(sKey) + "=; expires=Thu, 01 Jan 1970 00:00:00 GMT" + ( sDomain ? "; domain=" + sDomain : "") + ( sPath ? "; path=" + sPath : "");
    return true;
  },
  hasItem: function (sKey) {
    return (new RegExp("(?:^|;\\s*)" + encodeURIComponent(sKey).replace(/[\-\.\+\*]/g, "\\$&") + "\\s*\\=")).test(document.cookie);
  },
  keys: /* optional method: you can safely remove it! */ function () {
    var aKeys = document.cookie.replace(/((?:^|\s*;)[^\=]+)(?=;|$)|^\s*|\s*(?:\=[^;]*)?(?:\1|$)/g, "").split(/\s*(?:\=[^;]*)?;\s*/);
    for (var nIdx = 0; nIdx < aKeys.length; nIdx++) { aKeys[nIdx] = decodeURIComponent(aKeys[nIdx]); }
    return aKeys;
  }
};

var eeDate = {
  setDate: function (eewhen) {
    if (eewhen === 'today')
    return this.eeToday;
  },
  eeToday: new Date(),
};

var nIntervId;
 
function eefade() {
  nIntervId = setInterval(slidePopMeUp, 5000);
}
 
function slidePopMeUp() {
  setTimeout(function() {
    jQuery(".popMeUpGC .rotate.next").removeClass('next').addClass('queued');
    jQuery(".popMeUpGC .rotate.active").animate({opacity: '0'}, 200).removeClass('active').addClass('next');
    jQuery(".popMeUpGC .rotate.queued").animate({opacity: '1'}, 500).removeClass('queued').addClass('active');
  }, 1000);
}
 
function eefadeStop() {
  clearInterval(nIntervId);
}

function getRandomInt(min, max) {
  var eenum = Math.floor(Math.random() * (max - min + 1) + min);
  return eenum;
}

jQuery(document).ready(function($) {
  setTimeout(function() {
    var randnumber=getRandomInt(600, 650);
    eenow = new Date();
    eenow = eenow.getTime();
    ee_expiry = (60000*5);
    eethen = eenow - ee_expiry;

    if ( docCookies.hasItem('ee_expiry') ) { 
      if ( docCookies.getItem('ee_expiry') <= eethen ) {
        docCookies.setItem("ee_expiry", eenow, new Date(eenow+ee_expiry));
        docCookies.setItem("shoppingnumber", randnumber, new Date(eenow+ee_expiry));
        docCookies.setItem("boughtnumber", getRandomInt(10, 21), new Date(eenow+ee_expiry));
        docCookies.setItem("viewingnumber", getRandomInt(20, 25), new Date(eenow+ee_expiry));
      }
    }
    else {
      docCookies.setItem("ee_expiry", eenow, new Date(eenow+ee_expiry));
      docCookies.setItem("shoppingnumber", getRandomInt(100, 350), new Date(eenow+ee_expiry));
      docCookies.setItem("boughtnumber", getRandomInt(10, 25), new Date(eenow+ee_expiry));
      docCookies.setItem("viewingnumber", getRandomInt(3, 9), new Date(eenow+ee_expiry));
     }
      
      jQuery(".popMeUpGC").animate({bottom: '0px'}, 500);
      if(jQuery(".popMeUpGC p")) {
        jQuery(".popMeUpGC p").html(docCookies.getItem('shoppingnumber')+" people are reading this report right now.");
      }
      if(jQuery(".eenowviewing")) {
        eefade();
        jQuery(".eenowviewing").html(docCookies.getItem('boughtnumber')+" people purchased this in the last 2 hours.");
        jQuery(".eepurchased").html(docCookies.getItem('viewingnumber')+" people viewing this product right now.");
      }
  }, 1500);
  jQuery(".closeit").on('click', function(e) {
    e.preventDefault();
    if ( jQuery(this).hasClass('eecloseit')) { eefadeStop(); }
    jQuery(".popMeUpGC").slideUp('1000').addClass('noshow');
  });
});